#!/usr/bin/env python2
# -*- coding: utf-8 -*-

#-------------------------------------------------------------------------------
#"THE BEER-WARE LICENSE" (Revision 42):
#Simon Chabot <chabotsi@unice.fr> wrote this file. As long as you retain this
#notice you can do whatever you want with this stuff. If we meet some day, and
#you think this stuff is worth it, you can buy me a beer in return.
#-------------------------------------------------------------------------------

from __future__ import (unicode_literals, absolute_import, division,
                        print_function)

from PySide import QtGui
from PySide.QtCore import Signal, Qt, QPoint
from numpy import array, arange
from numpy.linalg import norm

from impactlocation_ui import Ui_Dialog as Ui_Impact

class ImpactLocationWindow(QtGui.QDialog):

    location_chosen = Signal([list], [], name='locationChosen')

    def __init__(self):
        super(ImpactLocationWindow, self).__init__()
        self.ui = Ui_Impact()
        self.ui.setupUi(self)

        self.worldmap = QtGui.QPixmap('img/earth.jpg')
        self.worldmap = self.worldmap.scaled(self.size(), Qt.KeepAspectRatio)
        self.ui.mapLabel.setPixmap(self.worldmap)

        #connections
        self.ui.mapLabel.mousePressEvent = self.set_clicked_color
        self.location_chosen.connect(self.close)

        self.positions = []

    def set_clicked_color(self, event):
        position = QPoint(event.pos())
        self.positions.append(position)

        if len(self.positions) < 2:
            return

        colors = [] #save every colors found between positions[0] and positions[1]

        A = array([self.positions[0].x(), self.positions[0].y()])
        B = array([self.positions[1].x(), self.positions[1].y()])
        coef = B - A

        for k in arange(0, 1, 0.01):
            p = k*coef + A
            color = QtGui.QColor.fromRgb(self.worldmap.toImage().pixel(QPoint(*p)) )
            colors.append(color)

        self.positions = [] #delete position for a furture selection
        self.location_chosen.emit(colors)
